@@ -17,7 +17,7 @@ use constant VALIDATE_IP       => eval 'require Data::Validate::IP;1';
 
 use constant DEBUG => $ENV{JSON_VALIDATOR_DEBUG} || 0;
 
-our $VERSION = '0.75';
+our $VERSION = '0.76';
 our @EXPORT_OK = qw(validate_json);
 
 my $HTTP_SCHEME_RE = qr{^https?:};
@@ -703,7 +703,7 @@ sub _load_yaml {
 sub _merge_errors {
   join ' ', map {
     my $e = $_;
-    @$e ? $e->[0]{message} : sprintf '(%s)', join '. ', map { $_->{message} } @$e;
+    (@$e == 1) ? $e->[0]{message} : sprintf '(%s)', join '. ', map { $_->{message} } @$e;
   } @_;
 }
 
@@ -729,7 +729,7 @@ JSON::Validator - Validate data against a JSON schema
 
 =head1 VERSION
 
-0.75
+0.76
 
 =head1 SYNOPSIS
 
